Auxiliary functions for controlling arguments for formatting the annotation tables that can be added to plots
generated via g_km().
Usage
control_surv_med_annot(
x = 0.8,
y = 0.85,
w = 0.32,
h = 0.16,
fill = TRUE,
digits = 4
)
control_coxph_annot(
x = 0.29,
y = 0.51,
w = 0.4,
h = 0.125,
fill = TRUE,
ref_lbls = FALSE
)Arguments
- x
(
proportion)
x-coordinate for center of annotation table.- y
(
proportion)
y-coordinate for center of annotation table.- w
(
proportion)
relative width of the annotation table.- h
(
proportion)
relative height of the annotation table.- fill
(
flagorcharacter)
whether the annotation table should have a background fill color. Can also be a color code to use as the background fill color. IfTRUE, color code defaults to"#00000020".- digits
(
integer(1))
number of significant digits for median survival time and confidence interval values. Defaults to4.- ref_lbls
(
flag)
whether the reference group should be explicitly printed in labels for the annotation table. IfFALSE(default), only comparison groups will be printed in the table labels.
Functions
control_surv_med_annot(): Control function for formatting the median survival time annotation table. This annotation table can be added ing_km()by settingannot_surv_med=TRUE, and can be configured using thecontrol_surv_med_annot()function by setting it as thecontrol_annot_surv_medargument.control_coxph_annot(): Control function for formatting the Cox-PH annotation table. This annotation table can be added ing_km()by settingannot_coxph=TRUE, and can be configured using thecontrol_coxph_annot()function by setting it as thecontrol_annot_coxphargument.
Examples
control_surv_med_annot()
#> $x
#> [1] 0.8
#>
#> $y
#> [1] 0.85
#>
#> $w
#> [1] 0.32
#>
#> $h
#> [1] 0.16
#>
#> $fill
#> [1] TRUE
#>
#> $digits
#> [1] 4
#>
control_surv_med_annot(digits = 2)
#> $x
#> [1] 0.8
#>
#> $y
#> [1] 0.85
#>
#> $w
#> [1] 0.32
#>
#> $h
#> [1] 0.16
#>
#> $fill
#> [1] TRUE
#>
#> $digits
#> [1] 2
#>
control_coxph_annot()
#> $x
#> [1] 0.29
#>
#> $y
#> [1] 0.51
#>
#> $w
#> [1] 0.4
#>
#> $h
#> [1] 0.125
#>
#> $fill
#> [1] TRUE
#>
#> $ref_lbls
#> [1] FALSE
#>