Learn R Programming

tern (version 0.9.12)

d_proportion_diff: Description of method used for proportion comparison

Description

[Stable]

This is an auxiliary function that describes the analysis in s_proportion_diff().

Usage

d_proportion_diff(conf_level, method, long = FALSE, method_only = FALSE)

Value

A string describing the analysis.

Arguments

conf_level

(proportion)
confidence level of the interval.

method

(string)
the method used for the confidence interval estimation.

long

(flag)
whether a long or a short (default) description is required.

method_only

(flag)
whether to return only the method description, without the confidence interval part of the description. If TRUE, conf_level and long are ignored.

See Also

prop_diff(), d_proportion(), d_test_proportion_diff()

Examples

Run this code
d_proportion_diff(0.95, "cmh_sato")
d_proportion_diff(0.95, "cmh_sato", long = TRUE)
d_proportion_diff(0.95, "cmh_sato", method_only = TRUE)

Run the code above in your browser using DataLab