Learn R Programming

tern (version 0.9.12)

d_test_proportion_diff: Description of the difference test between two proportions

Description

[Stable]

This is an auxiliary function that describes the analysis in s_test_proportion_diff.

Usage

d_test_proportion_diff(
  method,
  alternative = c("two.sided", "less", "greater"),
  method_only = FALSE
)

Value

A string describing the test from which the p-value is derived.

Arguments

method

(string)
one of chisq, cmh, cmh_sato, cmh_wh, fisher, or schouten; specifies the test used to calculate the p-value.

alternative

(string)
whether two.sided, or one-sided less or greater p-value should be displayed.

method_only

(flag)
whether to return only the method description, including the alternative hypothesis specification, without the "p-value" part of the description.

See Also

d_proportion(), d_proportion_diff()

Examples

Run this code
d_test_proportion_diff("cmh_sato")
d_test_proportion_diff("cmh_sato", alternative = "greater")
d_test_proportion_diff("cmh_sato", alternative = "greater", method_only = TRUE)

Run the code above in your browser using DataLab