A row is considered incomplete if at least one of its values is missing.
Missingness is determined using stats::complete.cases().
If one or more rows contain missing values, those rows are omitted and a
warning is issued reporting the number of omitted rows, unless quiet is
TRUE. The value of additional_message is appended to the warning message.
If no rows contain missing values, df is returned unchanged and no warning
is issued.