- lyt
(PreDataTableLayouts)
layout that analyses will be added to.
- vars
(character)
variable names for the primary analysis variable to be iterated over.
- strata
(character or NULL)
variable names indicating stratification factors.
- control
(list)
parameters for comparison details, specified by using the helper function
control_coxph(). Some possible parameter options are:
pval_method (string)
p-value method for testing the null hypothesis that hazard ratio = 1. Default
method is "log-rank" which comes from survival::survdiff(), can also be set to "wald" or "likelihood"
(from survival::coxph()).
ties (string)
specifying the method for tie handling. Default is "efron",
can also be set to "breslow" or "exact". See more in survival::coxph().
conf_level (proportion)
confidence level of the interval for HR.
alternative (string)
alternative hypothesis for the p-value test. Default is "two.sided",
can also be set to "less" or "greater" for one-sided testing. Note that one-sided testing is not
supported when pval_method = "likelihood".
- na_str
(string)
string used to replace all NA or empty values in the output.
- nested
(flag)
whether this layout instruction should be applied within the existing layout structure _if
possible (TRUE, the default) or as a new top-level element (FALSE). Ignored if it would nest a split.
underneath analyses, which is not allowed.
- ...
additional arguments for the lower level functions.
- var_labels
(character)
variable labels.
- show_labels
(string)
label visibility: one of "default", "visible" and "hidden".
- table_names
(character)
this can be customized in the case that the same vars are analyzed multiple
times, to avoid warnings from rtables.
- .stats
(character)
statistics to select for the table.
Options are: 'pvalue', 'hr', 'hr_ci', 'hr_ci_3d', 'lr_stat_df', 'n_tot', 'n_tot_events'
- .stat_names
(character)
names of the statistics that are passed directly to name single statistics
(.stats). This option is visible when producing rtables::as_result_df() with make_ard = TRUE.
- .formats
(named character or list)
formats for the statistics. See Details in analyze_vars for more
information on the "auto" setting.
- .labels
(named character)
labels for the statistics (without indent).
- .indent_mods
(named integer)
indent modifiers for the labels. Defaults to 0, which corresponds to the
unmodified default behavior. Can be negative.
- df
(data.frame)
data set containing all analysis variables.
- .ref_group
(data.frame or vector)
the data corresponding to the reference group.
- .in_ref_col
(flag)
TRUE when working with the reference level, FALSE otherwise.
- .var
(string)
single variable name that is passed by rtables when requested
by a statistics function.
- is_event
(flag)
TRUE if event, FALSE if time to event is censored.
- strat
Please use the strata argument instead.